<?php


namespace Controller;

use Traits\TResponse;
use Util\InstanceProvider;
use Util\Utilities;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;

class Soliserv
{
    use TResponse;

    /**
     * @var \Service\Soliserv
     */
    private $soliservService;

    public function __construct(\Service\Soliserv $soliservService)
    {
        $this->soliservService = $soliservService;
    }

    public function tarefaSoli(Request $request, Response $response)
    {
        try {
            $nrsoliserv = $request->getParameter('NRSOLISERV');
            $actions = $this->soliservService->findTarefa($nrsoliserv);
            $this->sendResponse($actions, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function findAllSoliserv(Request $request, Response $response)
    {
        try {
            $dynamicFilter = !empty($param['dynamic_filter'])  ? $param['dynamic_filter'] : null;
            $actions = $this->soliservService->findAllSoliserv($dynamicFilter);
            $this->sendResponse($actions, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function findItemTarefa(Request $request, Response $response)
    {
        try {

            $param = $request->getParameters();
            $nrtarefa = empty($param['NRTAREFA']) ? null : $param['NRTAREFA'];
            $nrtarefa = Utilities::fixBugNextFindArrayGrid($nrtarefa);
            $nrsoliserv = empty($param['NRSOLISERV']) ? null : $param['NRSOLISERV'];
            $actions = $this->soliservService->findItemTarefa($nrtarefa,$nrsoliserv);
            $this->sendResponse($actions, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function findAddItemTarefa(Request $request, Response $response)
    {
        try {

            $actions = $this->soliservService->findAddItemTarefa();
            $this->sendResponse($actions, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function findActivityDetails(Request $request, Response $response)
    {
        try {
            $param = $request->getParameters();
            $nrtarefas = $param['NRTAREFA'];
            $nrplativtare = $param['NRPLATIVTARE'];
            $cdFilial = $param['CDFILIAL'];

            $actions = $this->soliservService->findActivityDetails($nrtarefas, $nrplativtare, $cdFilial);
            $this->sendResponse($actions, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function findPlanativtare(Request $request, Response $response)
    {
        try {
            $param = $request->getParameters();
            $nrtarefas = empty($param['NRTAREFA']) ? null : $param['NRTAREFA'];

            $actions = $this->soliservService->findPlanativtare($nrtarefas);
            $this->sendResponse($actions, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function findProcessTotalized(Request $request, Response $response)
    {
        try {
            $param = $request->getParameters();
            $nrtarefas = empty($param['NRTAREFA']) ? null : $param['NRTAREFA'];

            $actions = $this->soliservService->findProcessTotalized($nrtarefas);
            $this->sendResponse($actions, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function maintenanceCost(Request $request, Response $response) {
        try{
            $params = $request->getParameters();
            $issueId = $params['CALL_RELATIONSHIP'];

            $budget = $this->soliservService->findMaintenanceCost($issueId);
            $data = array(
                "data" => $budget,
                "pagination" => array(
                    "limit" => 500000,
                    "page" => 1,
                    "total" => count($budget))
            );
            $this->sendResponse($data, 200);
        } catch(\Exception $e) {
            $this->sendResponse(['error' => $e->getMessage(), 'code' => $e->getCode()], 500);
        }
    }

    public function soliBudget(Request $request, Response $response) {
        try{
            $conditions = $request->getParameters();
            $budget = [];
            $SoliId = empty($conditions['Soli']) ? null : $conditions['Soli'];
            $nameProposal = empty($conditions['NAME_PROPOSAL']) ? null : $conditions['NAME_PROPOSAL'];
            $namePercent = empty($conditions['NAME_PERCENT']) ? null : $conditions['NAME_PERCENT'];
            $nameDiscount = empty($conditions['NAME_DISCOUNT']) ? null : $conditions['NAME_DISCOUNT'];
            if($SoliId){
                $budget = InstanceProvider::getService()->getSoliserv()->findBudget($SoliId,$nameProposal,
                    $nameDiscount,$namePercent);
            }
            foreach ($budget as &$item) {
                $item['PROPOSAL_VALUE'] = intval($item['PROPOSAL_VALUE']);
                if($item['PROPOSAL_VALUE_ESTIMAT'] !== null){
                    $item['PROPOSAL_VALUE_ESTIMAT'] = intval($item['PROPOSAL_VALUE_ESTIMAT']);
                }
                $item['MIN_QTY'] = null;
                if($item['CDITORCAPROD'] == '100'){
                    $item['MIN_QTY'] = 3;
                }else if($item['CDITORCAPROD'] == '150'){
                    $item['MIN_QTY'] = 4;
                }else if($item['CDITORCAPROD'] == '450'){
                    $item['MIN_QTY'] = 3;
                }
            }
            $data = array(
                "data" => $budget,
                "pagination" => array(
                    "limit" => 500000,
                    "page" => 1,
                    "total" => count($budget))
            );
            $this->sendResponse($data, 200);
        } catch(\Exception $e) {
            $this->sendResponse(['error' => $e->getMessage(), 'code' => $e->getCode()], 500);
        }
    }

    public function SoliBudgetSave(Request $request, Response $response){
        $params = $request->getParameters();
        try {
            $data = $params['DATA'];
            $dataMaintenance = $params['DATA_MAINTENANCE'];
            InstanceProvider::getService()->getSoliserv()->SoliBudgetSave($data);
            InstanceProvider::getService()->getSoliserv()->saveMaintenanceCost($dataMaintenance);

            $this->sendResponse([], 200);
        }
        catch(\Exception $e){
            $this->sendResponse(['error' => $e->getMessage(), 'code' => $e->getCode()], 500);
        }
    }

    public function SoliBudgetInstallmentsSave(Request $request, Response $response){
        $params = $request->getParameters();
        try {
            $nrsoliserv = $params['CALL_RELATIONSHIP'];
            $data = $params['DATA'];

            $this->soliservService->soliBudgetPlotsSave($data,$nrsoliserv);

            $this->sendResponse([], 200);
        }
        catch(\Exception $e){
            $this->sendResponse(['error' => $e->getMessage(), 'code' => $e->getCode()], 500);
        }
    }

    public function SoliBudgetPlots(Request $request, Response $response) {
        try{
            $conditions = $request->getParameters();
            $budget = [];
            $issueId = empty($conditions['Soli']) ? null : $conditions['Soli'];
            $namePlots = empty($conditions['NAME_PLOTS']) ? null : $conditions['NAME_PLOTS'];
            if($issueId){
                $budget = InstanceProvider::getService()->getSoliserv()->findSoliBudgetPlots($issueId, $namePlots);
            }
            foreach ($budget as &$item) {
                $item['ORDER_PLOTS_NUM'] = intval($item['ORDER_PLOTS_NUM']);
                $item['DAYS_PAYMENT'] = intval($item['DAYS_PAYMENT']);
                $item['PROPOSAL_VALUE_VIEW'] =$item['PROPOSAL_VALUE'];
                $item['PROPOSAL_VALUE'] = intval($item['PROPOSAL_VALUE']);
                $item['ORDER_PLOTS_NUM'] = intval($item['ORDER_PLOTS_NUM']);
                $item['VALUE_PLOTS'] = intval($item['VALUE_PLOTS']);
            }
            $data = array(
                "data" => $budget,
                "pagination" => array(
                    "limit" => 500000,
                    "page" => 1,
                    "total" => count($budget))
            );
            $this->sendResponse($data, 200);
        } catch(\Exception $e) {
            $this->sendResponse(['error' => $e->getMessage(), 'code' => $e->getCode()], 500);
        }
    }

    public function soliGenerateProposal(Request $request, Response $response) {
        try{
            $conditions = $request->getParameters();
            $nrsoliserv = $conditions['CALL_RELATIONSHIP'];
            $data = InstanceProvider::getService()->getSoliserv()->soliGenerateProposal($nrsoliserv);

            $this->sendResponse($data, 200);
        } catch(\Exception $e) {
            $this->sendResponse(['error' => $e->getMessage(), 'code' => $e->getCode()], 500);
        }
    }

    public function soliGenerateProposalValidate(Request $request, Response $response) {
        try{
            $conditions = $request->getParameters();
            $nrsoliserv = $conditions['CALL_RELATIONSHIP'];
            $validate = InstanceProvider::getService()->getSoliserv()->soliGenerateProposalValidate($nrsoliserv);

            $this->sendResponse($validate, 200);
        } catch(\Exception $e) {
            $this->sendResponse(['error' => $e->getMessage(), 'code' => $e->getCode()], 500);
        }
    }

    public function soliSMBudgetValidate(Request $request, Response $response) {
        try{
            $conditions = $request->getParameters();
            $nrsoliserv = $conditions['CALL_RELATIONSHIP'];
            $validate = InstanceProvider::getService()->getSoliserv()->soliSMBudgetValidate($nrsoliserv);

            $this->sendResponse($validate, 200);
        } catch(\Exception $e) {
            $this->sendResponse(['error' => $e->getMessage(), 'code' => $e->getCode()], 500);
        }
    }

    public function soliSpeCliValidate(Request $request, Response $response) {
        try{
            $conditions = $request->getParameters();
            $nrsoliserv = $conditions['CALL_RELATIONSHIP'];
            $validate = InstanceProvider::getService()->getSoliserv()->soliSpeCliValidate($nrsoliserv);

            $this->sendResponse($validate, 200);
        } catch(\Exception $e) {
            $this->sendResponse(['error' => $e->getMessage(), 'code' => $e->getCode()], 500);
        }
    }

    public function findValidadeAtividateGerada(Request $request, Response $response)
    {
        try {
            $param = $request->getParameters();
            $nrtarefas = empty($param['NRTAREFA']) ? '': $param['NRTAREFA'];
            $cdprocessos = empty($param['CDPROCESSOS']) ? array() : $param['CDPROCESSOS'];
            $cditemtrabalhos = empty($param['CDITEMTRABALHOS']) ? array() : $param['CDITEMTRABALHOS'];
            $actions = $this->soliservService->findValidadeAtividateGerada($nrtarefas,$cdprocessos,$cditemtrabalhos);
            $this->sendResponse($actions, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function generateActivitiesTaskSoli(Request $request, Response $response)
    {
        try {
            $param = $request->getParameters()['params'];
            $nrtarefa = empty($param['NRTAREFA']) ? '': $param['NRTAREFA'];
            $cdarvprocess = empty($param['CDARVPROCESS']) ? '': $param['CDARVPROCESS'];
            $nrsoliserv = empty($param['NRSOLISERV']) ? '': $param['NRSOLISERV'];
            $processos = empty($param['PROCESSES']) ? array() : $param['PROCESSES'];
            $itemtarefas = empty($param['ITEMTAREFAS']) ? array() : $param['ITEMTAREFAS'];
            $actions = $this->soliservService->generateActivitiesSoliserv($nrtarefa,$cdarvprocess,$nrsoliserv,$processos,$itemtarefas);
            $this->sendResponse($actions, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function saveItemTarefaSoli(Request $request, Response $response)
    {
        try {
            $params = $request->getParameters();
            foreach ($params['rowsSave'] as $param) {
                $cditemtrab = empty($param['CDITEMTRAB']) ? null : $param['CDITEMTRAB'];
                $nrtarefa = empty($param['NRTAREFA']) ? null : $param['NRTAREFA'];
                $nrprioittare = empty($param['NRPRIOITTARE']) ? null : $param['NRPRIOITTARE'];
                $nrcplximplem = empty($param['NRCPLXIMPLEM']) ? "0" : $param['NRCPLXIMPLEM'];
                $nrcplxitemtb = empty($param['NRCPLXITEMTB']) ? "0" : $param['NRCPLXITEMTB'];
                $nrcplxitemtb = preg_replace('/[^0-9]/', '', $nrcplxitemtb);
                $nrcplximplem = preg_replace('/[^0-9]/', '', $nrcplximplem);
                $this->soliservService->saveItemTarefaSoli($cditemtrab, $nrtarefa, $nrprioittare, $nrcplximplem, $nrcplxitemtb);
            }

        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function editItemTarefaSoli(Request $request, Response $response)
    {
        try {
            $params = $request->getParameters();
            foreach ($params['rowsSave'] as $param) {
                $nrtarefa = empty($param['NRTAREFA']) ? null : $param['NRTAREFA'];
                $nrsequittare = empty($param['NRSEQUITTARE']) ? null : $param['NRSEQUITTARE'];
                $nrprioittare = empty($param['NRPRIOITTARE']) ? null : $param['NRPRIOITTARE'];
                $nrcplximplem = empty($param['NRCPLXIMPLEM']) ? "0" : $param['NRCPLXIMPLEM'];
                $nrcplxitemtb = empty($param['NRCPLXITEMTB']) ? "0" : $param['NRCPLXITEMTB'];
                $nrcplxitemtb = preg_replace('/[^0-9]/', '', $nrcplxitemtb);
                $nrcplximplem = preg_replace('/[^0-9]/', '', $nrcplximplem);
                $this->soliservService->editItemTarefaSoli($nrsequittare, $nrtarefa, $nrprioittare, $nrcplximplem, $nrcplxitemtb);
            }

        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function findTarefaAllResponsavel(Request $request, Response $response)
    {
        try {
            $nrsoliserv = $request->getParameter('NRSOLISERV');
            $actions = $this->soliservService->findTarefaAllResponsavel($nrsoliserv);
            $this->sendResponse($actions, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function findTarefaAssunto(Request $request, Response $response)
    {
        try {
            $actions = $this->soliservService->findTarefaAssunto();
            $this->sendResponse($actions, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function findDefaultTaskSoli(Request $request, Response $response)
    {
        try {
            $nrsoliserv = $request->getParameter('NRSOLISERV');
            $actions = $this->soliservService->findDefaultTaskSoli($nrsoliserv);
            $this->sendResponse($actions, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function findProcessGeneration(Request $request, Response $response)
    {
        try {
            $actions = $this->soliservService->findProcessGeneration();
            $this->sendResponse($actions, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }


    public function findActivitiesGeneration(Request $request, Response $response)
    {
        try {
            $param = $request->getParameters();
            $cdarvprocess = empty($param['CDARVPROCESS']) ? null : $param['CDARVPROCESS'];
            $actions = $this->soliservService->findActivitiesGeneration($cdarvprocess);
            $this->sendResponse($actions, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function deleteTarefasSoli(Request $request, Response $response)
    {
        try {
            $params = $request->getParameters()['data'];
            foreach ($params as $param) {
                $nrtarefa = $param['NRTAREFA'];
                $this->soliservService->deleteTarefaSoli($nrtarefa);
            }
            $this->sendResponse([], 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function deleteItemTarefasSoli(Request $request, Response $response)
    {
        try {
            $params = $request->getParameters()['data'];
            foreach ($params as $param) {
                $nrtarefa = $param['NRTAREFA'];
                $nrsequittare = $param['NRSEQUITTARE'];
                $this->soliservService->deleteItemTarefasSoli($nrtarefa, $nrsequittare);
            }
            $this->sendResponse([], 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function deleteGridActivityS(Request $request, Response $response)
    {
        try {
            $params = $request->getParameters()['data'];
            foreach ($params as $param) {
                $nrtarefa = $param['NRTAREFA'];
                $cdfilial = $param['CDFILIAL'];
                $nrplativtare = $param['NRPLATIVTARE'];
                $idsitativtar =  $param['IDSITATIVTAR'];
                $cdoperresp = $param['CDOPERRESP'];
                $nmprocesso = $param['NMPROCESSO'];
                $cdoperincl = $param['CDOPERINCL'];
                $this->soliservService->deleteGridActivityS($nrtarefa, $cdfilial, $nrplativtare, $idsitativtar, $cdoperresp, $nmprocesso, $cdoperincl);
            }
            $this->sendResponse([], 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function downloadFileSpecificationTaskS(Request $request, Response $response)
    {
        try{
            $param = $request->getParameters();
            $nrsoliserv = $param['NRSOLISERV'];
            $cditemtrab = $param['CDITEMTRAB'];
            $this->soliservService->downloadFileSpecificationTaskS($nrsoliserv,$cditemtrab);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function linkDownloadBudgetSmSoliserv(Request $request, Response $response)
    {
        try{
            $param = $request->getParameters();
            $nrsoliserv = $param['NRSOLISERV'];
            $this->soliservService->getLinkDownloadBudgetSmSoliserv($nrsoliserv);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function openPageRequisite(Request $request, Response $response)
    {
        try{
            $param = $request->getParameters();
            $nrsoliserv = $param['NRSOLISERV'];
            var_dump($nrsoliserv);
            InstanceProvider::getService()->getCall()->getPageRequisite($nrsoliserv);
        } catch(\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function insertFileSpecificationTaskS(Request $request, Response $response)
    {
        try{
            $param = $request->getParameters();
            $nrsoliserv = $param['NRSOLISERV'];
            $cditemtrab = $param['CDITEMTRAB'];
            $document = $param['DOCUMENT'];
            $this->soliservService->insertFileSpecificationTaskS($nrsoliserv, $cditemtrab, $document);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function mergeFileSpecificationTaskS(Request $request, Response $response)
    {
        try{
            $param = $request->getParameters();
            $nrsoliserv = $param['NRSOLISERV'];
            $this->soliservService->mergeFileSpecificationTaskS($nrsoliserv);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function editSpecificationSoliserv(Request $request, Response $response)
    {
        try{
            $param = $request->getParameters();
            $nrsoliserv = $param['NRSOLISERV'];
            $cditemtrab = $param['CDITEMTRAB'];
            $docGoogle = $this->soliservService->editSpecificationSoliserv($nrsoliserv,$cditemtrab);
            $this->sendResponse($docGoogle, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function saveSpecificationSoliserv(Request $request, Response $response)
    {
        try{
            $param = $request->getParameters();
            $nrsoliserv = $param['NRSOLISERV'];
            $cditemtrab = $param['CDITEMTRAB'];
            $idGoogle = $param['ID_GOOGLE'];
            $this->soliservService->saveSpecificationSoliserv($nrsoliserv,$cditemtrab,$idGoogle);
            $this->sendResponse([], 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function cancelSpecificationSoliserv(Request $request, Response $response)
    {
        try{
            $param = $request->getParameters();
            $idGoogle = $param['ID_GOOGLE'];
            $this->soliservService->cancelSpecificationSoliserv($idGoogle);
            $this->sendResponse([], 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function editGridActivityS(Request $request, Response $response)
    {
        try{
            $params = $request->getParameters();
            foreach ($params['rowsSave'] as $param) {
                $cdfilial = $param['CDFILIAL'];
                $nrtarefa = $param['NRTAREFA'];
                $nrplativtare = $param['NRPLATIVTARE'];
                $nrprioativtr = $param['NRPRIOATIVTR'];
                $cdoperresp = $param['CDOPERRESP'];
                $qthrinfativtar = $param['QTHRINFATIVTAR'];
                $this->soliservService->editGridActivityS($cdfilial, $nrtarefa, $nrplativtare, $nrprioativtr,
                     $cdoperresp,$qthrinfativtar);
            }
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function saveTarefaSoli(Request $request, Response $response)
    {
        try {
            $params = $request->getParameters();
            foreach ($params['rowsSave'] as $param) {
                $cdassunto = empty($param['CDASSUNTO']) ? null : $param['CDASSUNTO'];
                $cdoperresp = empty($param['CDOPERRESP']) ? null : $param['CDOPERRESP'];
                $dsrefetarefa = empty($param['DSREFETAREFA']) ? null : $param['DSREFETAREFA'];
                $idorigtare = empty($param['IDORIGTARE']) ? null : $param['IDORIGTARE'];
                $nrpriotarefa = empty($param['NRPRIOTAREFA']) ? null : $param['NRPRIOTAREFA'];
                $nrsoliserv = empty($param['NRSOLISERV']) ? null : $param['NRSOLISERV'];
                $this->soliservService->saveTarefaSoli($nrsoliserv, $cdassunto, $cdoperresp, $dsrefetarefa, $idorigtare, $nrpriotarefa);
            }

        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function validateFornwardSoli(Request $request, Response $response)
    {
        try {
            $params = $request->getParameters();
            $nrsoliserv = empty($params['NRSOLISERV']) ? null : $params['NRSOLISERV'];
            $validate = $this->soliservService->validateFornwardSoli($nrsoliserv);
            $this->sendResponse(['VALIDATE' => $validate], 200);

        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function editTarefaSoli(Request $request, Response $response)
    {
        try {
            $params = $request->getParameters();
            foreach ($params['rowsSave'] as $param) {
                $cdoperresp = empty($param['CDOPERRESP']) ? null : $param['CDOPERRESP'];
                $dsrefetarefa = empty($param['DSREFETAREFA']) ? null : $param['DSREFETAREFA'];
                $nrpriotarefa = empty($param['NRPRIOTAREFA']) ? null : $param['NRPRIOTAREFA'];
                $nrtarefa = empty($param['NRTAREFA']) ? null : $param['NRTAREFA'];
                $this->soliservService->editTarefaSoli($nrtarefa, $cdoperresp, $dsrefetarefa, $nrpriotarefa);
            }

        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function saveItemTaskSoli(Request $request, Response $response)
    {
        try {
            $param = $request->getParameters();
            $nrsoliorig = $param['NRSOLIORIG'];
            $nrsoliserv = $param['NRSOLISERV'];
            $nrtarefa = $param['NRTAREFA'];
            $dsrefetarefa = $param['DSREFETAREFA'];
            $this->soliservService->saveItemTaskSoli($nrsoliorig, $nrsoliserv, $nrtarefa, $dsrefetarefa);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function qryCliente(Request $request, Response $response)
    {
        try {
            $actions = $this->soliservService->qryCliente();
            $this->sendResponse($actions, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function validaQryCliente(Request $request, Response $response)
    {
        try {
            $cdcliente = $request->getParameter('CDCLIENTE');
            $actions = $this->soliservService->validaQryCliente($cdcliente);
            $this->sendResponse($actions, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function validaqryPesqLicencaUso(Request $request, Response $response)
    {
        try {
            $cdcliente = $request->getParameter('CDCLIENTE');
            $actions = $this->soliservService->validaqryPesqLicencaUso($cdcliente);
            $this->sendResponse($actions, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function qryPesqLicencaUso(Request $request, Response $response)
    {
        try {
            $cdcliente = $request->getParameter('CDCLIENTE');
            $actions = $this->soliservService->qryPesqLicencaUso($cdcliente);
            $this->sendResponse($actions, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function qryCodAssunto(Request $request, Response $response)
    {
        try {
            $actions = $this->soliservService->qryCodAssunto();
            $this->sendResponse($actions, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function qryVersao(Request $request, Response $response)
    {
        try {
            $nrsoliserv = $request->getParameter('NRSOLISERV');
            $actions = $this->soliservService->qryVersao($nrsoliserv);
            $this->sendResponse($actions, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function qryPesqRelease(Request $request, Response $response)
    {
        try {
            $param = $request->getParameters();
            $cdgrupsist = !empty($param['CDPRODGRUP']) ? $param['CDPRODGRUP'] : null;
            $cdversgis = !empty($param['CDVERPRODUTO']) ? $param['CDVERPRODUTO'] : null;
            $actions = $this->soliservService->qryPesqRelease($cdgrupsist, $cdversgis);
            $this->sendResponse($actions, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function qryPatch(Request $request, Response $response)
    {
        try {
            $param = $request->getParameters();
            $cdgrupsist = !empty($param['CDPRODGRUP']) ? $param['CDPRODGRUP'] : null;
            $cdversgis = !empty($param['CDVERPRODUTO']) ? $param['CDVERPRODUTO'] : null;
            $cdreleasever = !empty($param['CDRELVERPROD']) ? $param['CDRELVERPROD'] : null;
            $actions = $this->soliservService->qryPatch($cdgrupsist, $cdversgis, $cdreleasever);
            $this->sendResponse($actions, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function saveCadAutomatico(Request $request, Response $response)
    {
        try {
            $referencia = $request->getParameter('REFERENCIA');
            $cdcliente = $request->getParameter('CDCLIENTE');
            $nrlicencauso = $request->getParameter('NRLICENCAUSO');
            $cdassunto = $request->getParameter('CDASSUNTO');
            $nrsoliserv = $request->getParameter('NRSOLISERV');
            $versoes = $request->getParameter('VERSAO');
            $actions = $this->soliservService->saveCadAutomatico($referencia, $cdcliente, $nrlicencauso, $cdassunto, $versoes, $nrsoliserv);
            $this->sendResponse($actions, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function qryProjeto(Request $request, Response $response)
    {
        try {
            $nrsoliserv = $request->getParameter('NRSOLISERV');
            $actions = $this->soliservService->qryProjeto($nrsoliserv);
            $this->sendResponse($actions, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }


    public function saveDescriptionActivityDetails(Request $request, Response $response)
    {
        try {
            $param = $request->getParameters();
            $cdfilial = $request->getParameter('CDFILIAL');
            $nrtarefa = $request->getParameter('NRTAREFA');
            $nrplativtare = $request->getParameter('NRPLATIVTARE');
            $description = !empty($param['DESCRIPTION']) ? $param['DESCRIPTION'] : null;
            $actions = $this->soliservService->saveDescriptionActivityDetails($cdfilial, $nrtarefa, $nrplativtare, $description);
            $this->sendResponse($actions, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }
}
